****************************************************************************
****************************************************************************
*****       UNU-WIDER/ATI Bottom-up tax gap toolkit				   *****
****************************************************************************
****************************************************************************

 
* Made by: Kwabena Adu-Ababio (kwabena@wider.unu.edu), Sebastian Castillo (), 
* Mostafa Bahbah and Amina Ebrahim

* Early version built on:  	25/01/24

* This version builds on:	"

* This do file:Uploads, Cleans & Merges Admin Data from the Renenue Authority
*				and implements a prediction model for tax gap analysis
*							 

* Raw data will go to:	 	"
*							C:\Users\select path\Cleaning\Excel

* Cleaned data will go to: 		"
*							C:\Users\select path\Cleaning\Data

  /*Spell out the changes.....*/
* Edited: DD/MM/YY by Kwabena: Started toolkit commands
* Edited: DD/MM/YY by Kwabena: Corrected dup0 & dup1 variables
* Edited: 04/04/24 by "Kwabena":  Incorporated Jukka's comments
* Edited: 11/07/24 by "Mostafa": Incorporate Gerald's, Bruce's, Jukka's and Sebastian's comments and suggestions about duplicates of tax returns. The step 5 in the first stage was repeated in step 6 to ensure all variables have the same names.

  
*							 

*V4
/*------------------------------------------------------------------------------

First Stage:

1. Install and Update Necessary Packages
2. Preparing Stata Environment
3. Setting Up Global Directory Paths
4. Importing Data
5. Renaming Variables and Saving the Data
6. Importing, renaming, and saving additional data files if the data comes in multiple files
------------------------------------------------------------------------------*/

/// 1. Install and Update Necessary Packages
* Install "usepackage", which allows for checking if other packages are installed:
*cap ssc install usepackage

* Install (and update) required packages, if not already installed (and updated):
*usepackage unique mdesc savesome xls2dta rmfiles, near /*add to update list if...*/

* General: Comments/code lines requiring edits in GREEN


version 14   /* Use Stata Version 14 */

/// 2. Preparing Stata Environment
set more off
clear matrix
set linesize 200
set matsize 800
cap log close

/// 3. Setting Up Global Directory Paths
global dir "<YOUR PATH>\"


global data 	"$dir\Data"
global graphs 	"$dir\Graphs"
global xlsout 	"$dir\Excel"
global dopath 	"$dir\Dofile"
global results 	"$dir\Results"
global log     	"$dir\Log"
**# Bookmark #1
log using "$log\Tax Gaps data prep.log", replace


/// 4. Importing Data
import delimited "$xlsout\<Your_CIT,PIT,or VAT_returns_Data_1st_File>.dsv",clear  /* Note: 1- 'import delimited' is employed to import a delimited text file format (such as CSV, TSV, DSV). If the file is in a different delimited text format (such as CSV), ensure to adjust the extension after the filename accordingly.2- If the data file is in xlsx format, we use the 'import excel' command like this example: (import excel "$xlsout\<Your_CIT,PIT,or VAT_returns_Data_1st_File>.xlsx", clear)*/

format tpin %15.0g  // make Psuedo tax ID visible


/// 5. Renaming Variables and Saving the Data
rename actvty_isic_code isic_code
rename provincename province
rename rtn_id returnid
rename form_name returntype

/*Additional checks must be made on formats for filing and return dates fiscal year, province and industry codes. Verify these variables*/

*save as STATA data
save "$data\<Your_CIT,PIT,or VAT_returns_Data_1st_File>.dta", replace  

/// 6. Importing, renaming, and saving additional data files if the data comes in multiple files
import delimited "$xlsout\<Your_CIT,PIT,or VAT_returns_Data_2nd_File>.dsv",clear  /* Note:  1- 'import delimited' is employed to import a delimited text file format (such as CSV, TSV, DSV). If the file is in a different delimited text format (such as CSV), ensure to adjust the extension after the filename accordingly.2- If the data file is in xlsx format, we use the 'import excel' command like the following example: import excel "$xlsout\<Your_CIT,PIT,or VAT_returns_Data_2nd_File>.xlsx", clear*/
format tpin %15.0g  // make Psuedo tax ID visible

rename actvty_isic_code isic_code
rename provincename province
rename rtn_id returnid
rename form_name returntype

*save as STATA data
save "$data\<Your_CIT,PIT,or VAT_returns_Data_2nd_File>.dta", replace


**Activity above applies to CIT, PIT, and VAT returns


/*------------------------------------------------------------------------------

Second Stage: Data Management Process for VAT, CIT, and PIT  

1. Dealing with Duplicates
2. Appending Datasets
3. Dealing with Duplicates if Data Comes in multiple files
4. Sorting, Reordering, Collapsing, and Saving Data
------------------------------------------------------------------------------*/

/*VAT*/

/// 1. Dealing with Duplicates
use "$data\<Your_VAT_returns_Data_1st_File>.dta", clear

duplicates tag rtn_year tpin month, gen(dup0)  // tag duplicates
tabulate dup0  // display the duplication table
browse rtn_year tpin month broad_sector outvat dup0 if dup0 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same period (eg, month, year) and taxpayer (tpin). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin month: egen latest0 = max(rtn_year) if dup0 != 0  // generate the latest return for duplicates
drop if rtn_year != latest0 & dup0 != 0  // drop if not the latest return

duplicates drop rtn_year tpin month, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin month, gen(dup0)  // re-tag duplicates to check for any remaining
assert dup0 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup0 latest0  // drop created variables

/*Note: If the VAT return data comes in more than one file, you should do the second and third steps; otherwise, ignore these steps and go directly to the fourth step. */

/// 2. Appending Datasets
/*Append datasets to check if variables are consistent in each set-DO THIS IF DATA COMES IN multiple files*/
append using "$data\<Your_VAT_returns_Data_2nd_File>.dta"  
browse // Verify data after combining for empty columns


/// 3. Dealing with Duplicates if Data Comes in multiple files
duplicates tag rtn_year tpin month, gen(dup1)  // tag duplicates
tabulate dup1  // display the duplication table
browse rtn_year tpin month broad_sector outvat dup1 if dup1 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same period (eg, month, year)  and taxpayer (tpin). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin month: egen latest1 = max(rtn_year) if dup1 != 0  // generate the latest return for duplicates
drop if rtn_year != latest1 & dup1 != 0  // drop if not the latest return

duplicates drop rtn_year tpin month, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin month, gen(dup1)  // re-tag duplicates to check for any remaining
assert dup1 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup1 latest1  // drop created variables

/// 4. Sorting, Reordering, Collapsing, and Saving Data
sort rtn_year tpin
order rtn_year tpin isic_code broad_sector regdate town_name province returnid returnstatus returntype

*Collapse VAT to annual level
collapse (sum) invat outvat vat_due vat_vars, by(tpin rtn_year)

*save as STATA data
save "$data\vat.dta", replace, replace  //for VAT Annual returns



/*CIT*/

/// 1. Dealing with Duplicates
use "$data\<Your_CIT_returns_Data_1st_File>.dta", clear
duplicates tag rtn_year tpin, gen(dup0)  // tag duplicates
tabulate dup0  // display the duplication table
browse rtn_year tpin broad_sector totalfixedassets accumulateddepreciation dup0 if dup0 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same taxpayer (tpin) and year (rtn_year). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin: egen latest0 = max(rtn_year) if dup0 != 0  // generate the latest return for duplicates
drop if rtn_year != latest0 & dup0 != 0  // drop if not the latest return

duplicates drop rtn_year tpin, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin, gen(dup0)  // re-tag duplicates to check for any remaining
assert dup0 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup0 latest0  // drop created variables

/*Note: If the CIT return data comes in more than one file, you should do the second and third steps; otherwise, ignore these steps and go directly to the fourth step. */

/// 2. Appending Datasets
/*Append datasets to check if variables are consistent in each set-DO THIS IF DATA COMES IN multiple files*/
append using "$data\<Your_CIT_returns_Data_2nd_File>.dta"
browse // Verify data after combining for empty columns


/// 3. Dealing with Duplicates if Data Comes in Multiple Files
duplicates tag rtn_year tpin, gen(dup1)  // tag duplicates
tabulate dup1  // display the duplication table
browse rtn_year tpin broad_sector totalfixedassets accumulateddepreciation dup1 if dup1 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same taxpayer (tpin) and year (rtn_year). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin: egen latest1 = max(rtn_year) if dup1 != 0  // generate the latest return for duplicates
drop if rtn_year != latest1 & dup1 != 0  // drop if not the latest return

duplicates drop rtn_year tpin, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin, gen(dup1)  // re-tag duplicates to check for any remaining
assert dup1 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup1 latest1  // drop created variables

/// 4. Sorting, Reordering, and Saving Data
sort rtn_year tpin
order rtn_year tpin isic_code broad_sector regdate town_name province returnid returnstatus returntype


*Save as STATA data
save "$data\cit.dta", replace // CIT data are always annual





/*PIT (PAYE)*/

/// 1. Dealing with Duplicates
use "$data\<Your_PIT_returns_Data_1st_File>.dta", clear
duplicates tag rtn_year tpin month, gen(dup0)  // tag duplicates
tabulate dup0  // display the duplication table
browse rtn_year tpin month broad_sector gsalary dup0 if dup0 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same period (month) and taxpayer (tpin). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin month: egen latest0 = max(rtn_year) if dup0 != 0  // generate the latest return for duplicates
drop if rtn_year != latest0 & dup0 != 0  // drop if not the latest return

duplicates drop rtn_year tpin month, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin month, gen(dup0)  // re-tag duplicates to check for any remaining
assert dup0 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup0 latest0  // drop created variables


/*Note: If the CIT return data comes in more than one file, you should do the second and third steps; otherwise, ignore these steps and go directly to the fourth step. */

/// 2. Appending Datasets
/*Append datasets to check if variables are consistent in each set-DO THIS IF DATA COMES IN multiple files*/
append using "$data\<Your_PIT_returns_Data_2nd_File>.dta"
browse // Verify data after combining for empty columns


/// 3. Dealing with Duplicates if Data Comes in Multiple Files
duplicates tag rtn_year tpin month, gen(dup1)  // tag duplicates
tabulate dup1  // display the duplication table
browse rtn_year tpin month broad_sector gsalary dup1 if dup1 == 1  // verify if not a case of clear duplication

// Note: Tax authorities sometimes make multiple reviews or assessments. In this context, a duplicate refers to multiple records for the same period (month) and taxpayer (tpin). We want to keep the most updated pre-audit return and discard older versions or reviewed/assessed returns.
bys tpin month: egen latest1 = max(rtn_year) if dup1 != 0  // generate the latest return for duplicates
drop if rtn_year != latest1 & dup1 != 0  // drop if not the latest return

duplicates drop rtn_year tpin month, force // drop duplicates only if data clearly indicates duplication
duplicates tag rtn_year tpin month, gen(dup1)  // re-tag duplicates to check for any remaining
assert dup1 == 0  // confirm uniqueness of data by asserting no duplicates
drop dup1 latest1  // drop created variables


/// 4. Sorting, Reordering, Collapsing, and Saving Data
sort rtn_year tpin
order rtn_year tpin isic_code broad_sector regdate town_name province returnid returnstatus returntype


*Collapse PIT to annual level
collapse (sum) pit_due pit_vars, by(tpin rtn_year) 

*save as STATA data
save "$data\pit.dta", replace



/*------------------------------------------------------------------------------

Third Stage: Data Management Process for Audit Return Data

1. Importing Audit Data
2. Appending Audit Datasets
3. Dealing with Duplicates
4. Inspecting the date variables and ensuring consistent formats
5. Adjusting Total Assessments for Annual Audit Periods
6. Alternate Approach to Deal with Duplicates
7. Improvement and Checks


------------------------------------------------------------------------------*/

/// 1. Importing Audit Data
import excel "$xlsout\<Your_Audits_Data_1st_File>.xlsx", sheet("Sheet1") firstrow clear

**Run checks and make conformity changes on earlier data if needed ex below:
rename TPIN tpin

rename TOTALTAX totalassessments
  
format tpin %15.0g

/*Additional checks must be made on formats for audit and return dates, fiscal year, province and industry codes. Verify these variables and check the tax assessment variable*/

*save as STATA data
save "$data\<Your_Audits_Data_1st_File>.dta", replace

* The following part of this step is needed if audit data comes in more than one file (eg. two files)
import delimited "$xlsout\<Your_Audits_Data_2nd_File>.xlsx",clear 

rename TPIN tpin

rename TOTALTAX totalassessments
format tpin %15.0g  // make Psuedo tax ID visible

*save as STATA data
save "$data\<Your_Audits_Data_2nd_File>.dta", replace


/// 2. Appending Audit Datasets
/*Append datasets to check if variables are consistent in each set-DO THIS IF DATA COMES IN multiple files*/
append using "$data\<Your_Audits_Data_2nd_File>.dta"  
browse //Verify data after combining for empty columns

*save all Audit data into one STATA file
save "$data\<combined_audit_data>.dta", replace



///3. Inspecting the date variables and ensuring consistent formats
/*
Dates in audit data often comes in inconsistent formats that might cause problems if we did not convert it to Stata   
formats. 


Example of these dates are:
assessment_date
audit_started_date
audit_completion_date
audit_period
*/


// 3.1.Inspect the Date Variables(mandatory)

* Display a sample of the data
list assessment_date audit_started_date audit_completion_date  in 1/20

* Get a summary of unique values to identify different date formats
tabulate assessment_date, missing
tabulate audit_started_date, missing
tabulate audit_completion_date, missing

* Identify unique formats and common issues
sort assessment_date
browse if missing(date(assessment_date, "DMY")) & missing(date(assessment_date, "MDY")) & missing(date(assessment_date, "YMD")) & missing(date(assessment_date, "MYD"))

sort audit_started_date
browse if missing(date(audit_started_date, "DMY")) & missing(date(audit_started_date, "MDY")) & missing(date(audit_started_date, "YMD")) & missing(date(audit_started_date, "MYD"))

sort audit_completion_date
browse if missing(date(audit_completion_date, "DMY")) & missing(date(audit_completion_date, "MDY")) & missing(date(audit_completion_date, "YMD")) & missing(date(audit_completion_date, "MYD"))


* Note: audit_period is handled differently as it represents a range or multiple periods.

// 3.2.Manual Corrections(optional)
/*
This step is needed only if the browse commands in the previous step indicate cases that need manual corrections. Here, we replace these incorrect date formats with the correct ones.You need to amend the following example to fit into your case.
*/

* Example
replace assessment_date = "01/05/2019" if assessment_date == " 1-May" // Before "if", put the correct date format as DMY. After "if", put the date cases displayed in the last step.
replace assessment_date = "05/12/2018" if assessment_date == "05/012/2018" 
* Add more corrections as needed

replace audit_started_date = "01/07/2017" if audit_started_date == "1.7.20147" // Before "if", put the correct date format as DMY. After "if", put the date cases displayed in the last step.
replace audit_started_date = "10/04/2019" if audit_started_date == "10-Apr"
* Add more corrections as needed

replace audit_completion_date = "13/08/2020" if audit_completion_date == "13/8/20120" // Before "if", put the correct date format as DMY. After "if", put the date cases displayed in the last step.
replace audit_completion_date = "13/06/2021" if audit_completion_date == "13/JU//21"
* Add more corrections as needed


// 3.3.Identify and Correct Remaining Incorrect Dates to Stata format(mandatory)
local date_vars assessment_date audit_started_date audit_completion_date

* Update the corrected dates after manual corrections
foreach var of local date_vars {
    * Generate the corrected date variable
    generate `var'_new = date(`var', "DMY")
    format `var'_new %td
    replace `var'_new = date(`var', "DM20Y") if missing(`var'_new)
    replace `var'_new = date(`var', "MDY") if missing(`var'_new)
    replace `var'_new = date(`var', "Y") if missing(`var'_new)

    * Handle remaining cases where date conversion failed
    generate `var'_numeric = `var' if missing(`var'_new)
    destring `var'_numeric, replace force
    replace `var'_new= `var'_numeric if missing(`var'_new)
    
    * Clean up temporary variables
    drop `var'_numeric  
}

* Clean up old date variables
drop assessment_date audit_started_date audit_completion_date

* Renaming new date variables as old ones 
rename assessment_date_new  assessment_date
rename audit_started_date_new  audit_started_date
rename audit_completion_date_new  audit_completion_date


// 4.4.Checking problems
* Generate a new variable to flag date problems
generate date_problem=(audit_started_date > audit_completion_date)
tabulate date_problem		// tabulate the date_problem variable to see the frequency of issues
browse audit_started_date audit_completion_date if date_problem==1  // Browse the records with date problems

replace date_problem=. if audit_started_date==. | audit_completion_date==.

* Swap the start and completion dates of audit for records with date problems
generate s = audit_started_date
generate e = audit_completion_date
replace audit_completion_date = s if date_problem==1
replace audit_started_date = e if date_problem==1

drop s e date_problem 

// 4.5. Amending the dates to keep only the month and year
generate sm=month(audit_started_date)
generate sy=year(audit_started_date)
generate started_date=ym(sy,sm)
format started_date %tm
label var started_date "Date when audit started"


generate em=month(audit_completion_date)
generate ey=year(audit_completion_date)
generate audit_completion=ym(ey,em)
format audit_completion %tm
label var audit_completion "Date when audit ended"
drop sy sm ey em


// 3.6. Dealing with the period coverd by audit

* Display a sample of the data
list audit_period in 1/20

**# Bookmark #1
**Some revenue authorities may have "audit period" split in two separate variables
*"audit period from" and "audit period to". Check these variables if this is the case
list auditperiodfrom auditperiodto in 1/20


* Get a summary of unique values to identify different date formats
tabulate audit_period, missing    // Here we indicate any kind of incorrect date formats that we should fix in following step.
**# Bookmark #2
*OR
tabulate auditperiodfrom, missing
tabulate auditperiodto, missing

// 3.6.1. Manual Corrections(optional)
/*
This step is needed only if the browse commands in the previous step indicate cases that need manual corrections. Here, we replace these incorrect date formats with the correct ones.You need to amend the following example to fit into your case.
*/
*Example1
replace audit_period = "2020 2021" if audit_period == "20/21"
replace audit_period = "2017 2018" if audit_period == "20017-2018"
// Add more corrections as needed based on your data inspection

*Example2 (Create audit period variable from two separate variables)
tostring auditperiodfrom auditperiodto, replace 
g audityearfrom=substr(auditperiodfrom, 1,4)
g audityearto=substr(auditperiodto, 1,4)
g audit_period=audityearfrom+ " " + audityearto



* Replace any character that is not a digit (0-9) or space with a space
forvalues i = 1/10 {
    replace audit_period = regexr(audit_period, "[^0-9 ]", " ")
}


* Here we split the audit_period to two variables for first and last year covered by audit

generate p= audit_period

split p,destring	

gen initial_period=p1
label var initial_period "First year covered by auditing" 

gen p22 = p2 if p3==.
replace p22 = p4 if p22==.
gen final_period=p22
label var final_period "Final year covered by auditing"

drop p p1 p2 p3 p4 p22 audit_period


///4. Adjusting Total Assessments for Annual Audit Periods
/* The audit assessment variable, donat the audit output, this can be positive or negative, however we can consider only positive outcome(audit_assessment) as proxy of tax evasion we consider positive or zero values.*/

replace totalassessments = 0 if totalassessments < 0 

* The following code gives the number of total audit period
generate total_audit_period= 1 + (final_period - initial_period)

* To eliminate zero total assessments, we change all zero total audit periods to 1
replace total_audit_period=1 if total_audit_period==0

*Because the audits can be more than one year, we correct the audit effort to reflect the annual audit.*/
gen totalassessments_annual = totalassessments/total_audit_period


///5. Reshaping Audit data to create a audited_year variable from the audited periods to use it later when mergeing with tax return data

gen audited_year = .   // Generate a list of all audited years for each tpin

expand 1 + (final_period - initial_period) // Expand for the range between initial and final periods


//Assign Audited Years to Each Expanded Observation

bysort tpin: gen temp = _n
replace audited_year = initial_period + temp - 1
drop if audited_year > final_period
drop temp


//Rename as follows For mereging
rename audited_year rtn_year

/// 6. Dealing with Duplicates

/// 6.1. Dealing with Duplicates with Assessment Date
/*In this approach to deal with duplicates for Audit data: 
Often the data include audit assessment dates. These can be used to select which observations to drop in case of duplicates .  The code below drops all but the latest return year data which should not be affected by the audit*/

**assessment_date is the final assessment that the Revenue Authority had about a firm in a particular tax type/head
**All approaches can be used if all required variables are available.

// 6.1.1 Sort and Drop Duplicates Based on Assessment Date
gsort +tpin +rtn_year +tax_head +initial_period +final_period  -assessment_date // Sorting by tpin, rtn_year, tax_head, initial_period, final_period, and assessment_date in descending order
duplicates drop tpin rtn_year tax_head initial_period final_period , force // Dropping duplicates based on tpin, rtn_year, tax_head, initial_period, and final_period, keeping the latest assessment_date

// 6.1.2 Sort and Organize Variables
sort rtn_year tpin initial_period final_period  // Sorting the data for better organization
order rtn_year tpin initial_period final_period  isic_code broad_sector town_name province // Reordering variables for better merge and analysis
format tpin %15.0g // Formatting tpin for consistent display

//6.1.3. Check for Duplicates
unique rtn_year tpin initial_period final_period // Check for unique combinations of rtn_year, tpin, initial_period, and final_period
duplicates tag rtn_year tpin initial_period final_period , gen(dup1) // Tagging duplicates for further inspection
tabulate dup1 // Tabulate the number of duplicates found
browse rtn_year tpin totalassessments dup1 if dup1 == 1 // Browse cases where duplicates are found

// 6.1.4. Dropping Clear Duplicates
duplicates drop rtn_year tpin initial_period final_period , force // Dropping duplicates if the data is clearly duplicated
unique rtn_year tpin initial_period final_period  // Confirming the uniqueness of the data
drop dup1 // Dropping temporary duplicate variables

/// 6.2. Dealing without Duplicates without Assessment Date

unique rtn_year tpin initial_period final_period   // check for duplcates (there should be none)*If there are duplicates
unique rtn_year tpin initial_period final_period 
duplicates tag rtn_year tpin initial_period final_period , gen(dup0)
duplicates drop rtn_year tpin initial_period final_period , force // drop duplicates if confirmed
drop dup0

/// 7. Improvement and checks on Audit data if necessary
encode AuditType, gen(auditcode)  //Create variable for audit types 
recode auditcode (2/6 13=1) (8/12 14=2) (7=3), gen(audittype)
drop auditcode
lab define type_lbl 1"1.Comprehensive audit" 2"2.Issue audit" 3"3.Credibility check"  4"4.CIT Audit" 5"5.PIT Audit" 6"6.VAT audit" 7"7.Desk audit"  //Omit/Add audit type where necessary and applicable
label val audittype type_lbl
tabulate audittype
order tpin initial_period final_period audittype started_date audit_completion totalassessments  //Arrange audit variables as required

*save as STATA data
save "$data\audit.dta", replace


/*------------------------------------------------------------------------------

Fourth Stage: Merging CIT, PIT, and VAT with the Audit Data

------------------------------------------------------------------------------*/

/*MERGE ALL CIT, PIT, VAT DATAFILES to AUDIT-Unique identifiers to merge on are "TPIN" and "Return year".*/
	   
**Merge should be 1:1 using "TPIN" and "Return year" for VAT, CIT and PIT.

**With VAT	   
use "$data\audit.dta", clear

/* Note: Merging audit and tax data by the return year the audit was carried out.
This ensures the audit assessment is assigned to the correct return year for accurate analysis*/

merge 1:1 tpin rtn_year using "$data\vat.dta"  // how many firms with VAT returns have been audited?  

recode _merge (3=1) (2 =0) (1 =2), gen(vataudstat)   //create var for audited firms and flag firms that are audited but cannot be found in VAT data. Ideally, this should not happen if all audited VAT firms are found in VAT return data
drop 	_merge
label 	define vatstat_lbl 1"1.Match & Audited" 0"0.No Match not Audited" 2"2.No Match & Audited"
label 	val vataudstat vatstat_lbl
tabulate vataudstat  //Check and verify if label 0 and 2 are pausible
order 	tpin rtn_year vataudstat

**After check & verification create a dummy variable VAT audited firms based on "vataudstat-NEEDED for BOTTOM_UP APPROACH"
generate 	vataudited=1 if vataudstat==1|vataudstat==2 // firms who have been audited
replace vataudited=0 if vataudstat==0|vataudstat==.

*If VAT return data already tags audited firms with a variable "audit", gen firms ever been VAT audited dummy as:
egen nr_audits=total(audit), by(tpin)
generate ever_vataudited = (nr_audits>0)

tabulate 		vataudited
label var rtn_year "Return Year"
label var vataudited "VAT Audit Status"
label 	values vataudited		vataudited
label 	define	vataudited	0	"Unaudited", replace
label 	define	vataudited	1	"VAT Audited", add
label 	define	ever_vataudited	0	"never VAT Audited", replace
label 	define	ever_vataudited	1	"ever VAT Audited", add



*save final data
save "$data\vataudit.dta", replace


***With CIT	   
use "$data\audit.dta", clear

/* Note: Merging audit and tax data by the return year the audit was carried out.
This ensures the audit assessment is assigned to the correct return year for accurate analysis*/

merge 1:1 tpin rtn_year using "$data\cit.dta"  // how many firms with CIT returns have been audited?
recode _merge (3=1) (2 =0) (1 =2), gen(citaudstat)   //create var for audited firms and flag firms that are audited but cannot be found in CIT data. Ideally, this should not happen if all audited CIT firms are found in CIT return data
drop _merge
label define citaudstat_lbl 1"1.Match & Audited" 0"0.No Match not Audited" 2"2.No Match & Audited"
label val citaudstat citstat_lbl
tabulate citaudstat  //Check and verify if label 0 and 2 are pausible
order tpin rtn_year citaudstat

**After check & verification create a dummy variable CIT audited firms based on "citaudstat-NEEDED for BOTTOM_UP APPROACH"
generate citaudited=1 if citaudstat==1|citaudstat==2 // firms who have been audited
replace citaudited=0 if citaudstat==0|citaudstat==.

*****If CIT return data already tags audited firms with a variable "audit", gen firms ever been CIT audited dummy as:
egen nr_audits=total(audit), by(tpin)
gen ever_citaudited = (nr_audits>0)

tabulate citaudited
label var rtn_year "Return Year"
label var citaudited "CIT Audit Status"
label values citaudited		citaudited
label 	define	citaudited	0	"Unaudited", replace
label 	define	citaudited	1	"CIT Audited", add
label 	define	ever_citaudited	0	"never CIT Audited", replace
label 	define	ever_citaudited	1	"ever CIT Audited", add


*save final data
save "$data\citaudit.dta", replace


**With PIT
use "$data\audit.dta", clear

/* Note: Merging audit and tax data by the return year the audit was carried out.
This ensures the audit assessment is assigned to the correct return year for accurate analysis*/
		  
merge 1:1 tpin rtn_year using "$data\pit.dta"  // how many firms with PIT returms have been audited?

recode _merge (3=1) (2 =0) (1 =2), gen(pitaudstat)   //create var for audited firms and flag firms that are audited but cannot be found in PIT data. Ideally, this should not happen if all audited PIT firms are found in PIT return data
drop _merge
label define pitaudstat_lbl 1"1.Match & Audited" 0"0.No Match not Audited" 2"2.No Match & Audited"
lab val pitaudstat pitstat_lbl
tabulate pitaudstat  //Check and verify if label 0 and 2 are pausible
order tpin rtn_year pitaudstat

**After check & verification create a dummy variable PIT audited firms based on "pitaudstat-NEEDED for BOTTOM_UP APPROACH"
generate pitaudited=1 if pitaudstat==1|pitaudstat==2 // firms who have been audited
replace pitaudited=0 if pitaudstat==0|pitaudstat==.

*If PIT return data already tags audited firms with a variable "audit", gen firms ever been PIT audited dummy as:
egen nr_audits=total(audit), by(tpin)
gen ever_pitaudited = (nr_audits>0)

tabulate pitaudited
label var rtn_year "Return Year"
label var pitaudited "PIT Audit Status"
label values pitaudited		pitaudited
label 	define	pitaudited	0	"Unaudited", replace
label 	define	pitaudited	1	"PIT Audited", add
label 	define	ever_pitaudited	0	"never PIT Audited", replace
label 	define	ever_pitaudited	1	"ever PIT Audited", add


*save final data
save "$data\pitaudit.dta", replace

/*Data check and cleaning is complete and ready. Data files for bottom-up analysis
*** citaudit.dta --->CIT returns merged with audit data
*** pitaudit.dta --->PIT returns merged with audit data and 
*** vataudit.dta --->VAT returns merged with audit data*/.

**# Bookmark #2
log close

               /*BOTTOM-UP ANALYSIS BEGINS*/


